'''
============================================================
《HaaS框架下阿里云设备云端一体全链路应用开发》项目案例源码
案例：  03-设备向阿里云物联网平台上报属性
硬件：  XMF08A 蓝蜻蜓ESP32
设计：  小蜜蜂老师  欧浩源  广东职业技术学院
时间：  2022-08-25
更多资源详见：  www.xmf393.com
============================================================
'''
import time            
import network   
from machine import Pin   
from aliyunIoT import Device
import json

D3 = Pin(14,Pin.OUT,value = 0)
D4 = Pin(27,Pin.OUT,value = 0)
D5 = Pin(26,Pin.OUT,value = 0)
D6 = Pin(33,Pin.OUT,value = 0)

#######################################################################################
ssid = '你的路由器账号'
password = '你的路由器密码'

def connect_wifi():
    sta = network.WLAN(network.STA_IF)
    sta.active(True)
    print('=======welcome to:www.xmf393.com=======') 
    if not sta.isconnected():
        print('正在进行网络连接......')
        sta.connect(ssid,password)
        while not sta.isconnected():
            D3.on()
            time.sleep_ms(50)
            D3.off()
            time.sleep_ms(100)
    D3.on()
    print(sta.ifconfig())
    print('WIFI模块成功连接网络！')
    print('=======================================') 

#######################################################################################
productKey = "你创建的产品信息"              #物联网云平台申请到的productKey信息
deviceName = "设备名称"                   #物联网云平台申请到的deviceName信息
deviceSecret = "设备密码"     #物联网云平台申请到的deviceSecret信息
region = "cn-shanghai"                  #物联网云平台申请到的设备所在的地域名，如cn-shanghai

key_info = {
    'region': region,
    'productKey': productKey,
    'deviceName': deviceName,
    'deviceSecret': deviceSecret,
    'keepaliveSec': 60
}
#######################################################################################
f_connected = False

#回调函数：连接成功
def on_connect(data):
    global f_connected       
    f_connected = True
    D4.on()

#属性上报函数
def post_props(): 
    for i in range(1,4):
        D6.on()
        value = {'mtemp':i*2,'mhumi':i*5,'LightVolt':i*10,'PowerSwitch':1}
        data = {'params': json.dumps(value)}
        ret = aliyunIoT_device.postProps(data)
        print(data)
        if ret == 0 :
            print('属性上报成功')
        else :
            print('属性上报失败')
        time.sleep(1)
        D6.off()
        time.sleep(1)

#主函数
if __name__ == '__main__':
    # 连接WIFI网络
    connect_wifi()
    # 将三元组信息设置到iot组件中
    aliyunIoT_device = Device()
    # 设定连接到物联网平台的回调函数，如果连接物联网平台成功，则调用on_connect函数
    aliyunIoT_device.on(aliyunIoT_device.ON_CONNECT, on_connect)
    # 启动连接阿里云物联网平台过程
    aliyunIoT_device.connect(key_info)
    # 等待设备成功连接到物联网平台
    while f_connected == False:
        pass

    # 向阿里云物联网平台上报3次4个属性
    post_props()

    # 关闭设备对象，断开平台连接，销毁线程资源
    D5.on()
    ret = aliyunIoT_device.end()
    if ret == 0:
        D4.off()
        D5.off()
